@@ -139,9 +139,9 @@ class PD_input:
         temp_data[channels]=temp_data[channels].subtract(baseline,axis='index')
         temp_data['Mean']=temp_data[channels].mean(axis=1)
         
-        if include_negatives==False & random==False:
+        if (include_negatives==False and random==False):
             temp_data[temp_data < 0]=0 # replace negative abundances with 0
-        elif include_negatives == False & random ==True:
+        elif (include_negatives == False and random ==True):
             for channel in channels:
                 temp_data[channel] = np.where(temp_data[channel] < 0, random_float.random_sample(size=len(temp_data)),temp_data[channel])
         elif include_negatives == True:
